==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/File/SaveAs/ts/SaveAs_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>SaveAs</name>
    <message>
        <location filename="../SaveAs.js" line="+32"/>
        <source>Load/Save</source>
        <translation>Charger/Enregistrer</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Save as</source>
        <translation>Enregistrer sous</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>No export filters</source>
        <translation>Pas de filtres d&apos;exportation</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>No export filters have been found. Aborting...</source>
        <translation>Pas de filtres d&apos;exportation ont été trouvés. Abandon...</translation>
    </message>
    <message>
        <location line="+53"/>
        <source>Format:</source>
        <translation>Format :</translation>
    </message>
    <message>
        <location filename="../SaveAsInit.js" line="+2"/>
        <source>Save &amp;As...</source>
        <translation>Enregistrer &amp;sous...</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+32"/>
        <source>Default format:</source>
        <translation>Format par défaut:</translation>
    </message>
    <message>
        <location line="+50"/>
        <source>Show warning when saving to a file format that does not support 24bit colors</source>
        <translation>Afficher un avertissement lors de l&apos;enregistrement d&apos;un format de fichier qui ne prend pas en charge les couleurs 24 bits</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/File/SaveAs/ts/SaveAs_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>SaveAs</name>
    <message>
        <location filename="../SaveAs.js" line="+38"/>
        <source>Load/Save</source>
        <translation>Charger/Enregistrer</translation>
    </message>
    <message>
        <source>Save as</source>
        <translation type="vanished">Enregistrer sous</translation>
    </message>
    <message>
        <source>No export filters</source>
        <translation type="vanished">Pas de filtres d&apos;exportation</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>File</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>No export filters have been found. Aborting...</source>
        <translation>Pas de filtres d&apos;exportation ont été trouvés. Abandon...</translation>
    </message>
    <message>
        <location line="+65"/>
        <source>Format:</source>
        <translation>Format :</translation>
    </message>
    <message>
        <location filename="../SaveAsInit.js" line="+2"/>
        <source>Save &amp;As...</source>
        <translation>Enregistrer &amp;sous...</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>File Dialog</source>
        <translation>Dialogue de fichier</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Use system file dialog</source>
        <translation>Utilisez dialogue de fichier du système</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Saving</source>
        <translation>Enregistrer</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Default format:</source>
        <translation>Format par défaut:</translation>
    </message>
    <message>
        <location line="+37"/>
        <source>Show warning when saving to a file format that does not support 24bit colors</source>
        <translation>Afficher un avertissement lors de l&apos;enregistrement d&apos;un format de fichier qui ne prend pas en charge les couleurs 24 bits</translation>
    </message>
</context>
</TS>
